mailr19657 - /branches/relax_disp/lib/dispersion/equations.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on May 03, 2013 - 21:47:
Author: bugman
Date: Fri May  3 21:47:26 2013
New Revision: 19657

URL: http://svn.gna.org/viewcvs/relax?rev=19657&view=rev
Log:
Renamed the lib.dispersion.equations.fast_2site() function to r2eff_LM63().

The number of relaxation times has also been replaced by the number of 
dispersion points.


Modified:
    branches/relax_disp/lib/dispersion/equations.py

Modified: branches/relax_disp/lib/dispersion/equations.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/lib/dispersion/equations.py?rev=19657&r1=19656&r2=19657&view=diff
==============================================================================
--- branches/relax_disp/lib/dispersion/equations.py (original)
+++ branches/relax_disp/lib/dispersion/equations.py Fri May  3 21:47:26 2013
@@ -51,8 +51,8 @@
     return -1.0 / relax_time * log(float(I) / I_ref)
 
 
-def fast_2site(params=None, cpmg_frqs=None, back_calc=None, num_times=None):
-    """Back calculate the effective transversal relaxation rate (R2eff).
+def r2eff_LM63(params=None, cpmg_frqs=None, back_calc=None, 
num_disp_points=None):
+    """Back calculate R2eff.
 
     The currently supported equation is that for CPMG relaxation dispersion 
in the fast exchange limit:
 
@@ -63,7 +63,6 @@
             - Tollinger et al., JACS, 2001, 123, 11341-11352 (equation 2)
     """
 
-    # Loop over the time points.
-    for i in range(num_times):
-        # Back calculate.
+    # Loop over the time points, back calculating the R2eff value.
+    for i in range(num_disp_points):
         back_calc[i] = params[0] + params[1] * (1 - 2 * tanh(params[2] / (2 
* 4 * cpmg_frqs[i])) * ((4 * cpmg_frqs[i] ) / params[2]))




Related Messages


Powered by MHonArc, Updated Fri May 03 22:00:01 2013